@@ -52,7 +52,7 @@ class Command(BaseCommand):
             crons_to_run = map(lambda x: get_class(x), cron_class_names)
         except:
             error = traceback.format_exc()
-            print 'Make sure these are valid cron class names: %s\n%s' % (cron_class_names, error)
+            print('Make sure these are valid cron class names: %s\n%s' % (cron_class_names, error))
             sys.exit()
 
         for cron_class in crons_to_run:
@@ -70,7 +70,7 @@ def run_cron_with_cache_check(cron_class, force=False, silent=False):
     if not cache.get(cron_class.__name__) or getattr(cron_class, 'ALLOW_PARALLEL_RUNS', False):
         timeout = DEFAULT_LOCK_TIME
         try:
-            timeout = settings.DJANGO_CRON_LOCK_TIME
+            timeout = cron_class.DJANGO_CRON_LOCK_TIME if getattr(cron_class, 'DJANGO_CRON_LOCK_TIME', False) else settings.DJANGO_CRON_LOCK_TIME
         except:
             pass
         cache.set(cron_class.__name__, timezone.now(), timeout)
@@ -79,5 +79,5 @@ def run_cron_with_cache_check(cron_class, force=False, silent=False):
         cache.delete(cron_class.__name__)
     else:
         if not silent:
-            print "%s failed: lock has been found. Other cron started at %s" % \
-                (cron_class.__name__, cache.get(cron_class.__name__))
+            print("%s failed: lock has been found. Other cron started at %s" % \
+                  (cron_class.__name__, cache.get(cron_class.__name__)))
